@@ -1,9 +1,9 @@
 use warnings;
 use strict;
 
-package Text::Parser 0.902;
+package Text::Parser 0.903;
 
-# ABSTRACT: Simplifies text parsing. Extensible to parse various grammars.
+# ABSTRACT: Simplifies text parsing. Easily extensible to parse various text formats.
 
 use Exporter 'import';
 our (@EXPORT_OK) = ();
@@ -33,12 +33,10 @@ use Try::Tiny;
 use Moose::Util 'apply_all_roles';
 use Moose::Util::TypeConstraints;
 
-coerce FileHandle => from GlobRef =>
-    via { FileHandle->new_from_fd( $$_, 'r' ) };
+subtype 'Text::Parser::Types::FileReadable' => as Str =>
+    where( \&_condition_FileReadable );
 
-subtype 'Text::Parser::Types::FileReadable' => as
-    Any => where { not defined $_ or ( $_ and -f $_ and -r $_ ) },
-    message {"\'$_\' is not a valid readable file"};
+sub _condition_FileReadable { $_ and -f $_ and -r $_; }
 
 enum 'Text::Parser::Types::MultilineType' => [qw(join_next join_last)];
 
@@ -284,11 +282,11 @@ __END__
 
 =head1 NAME
 
-Text::Parser - Simplifies text parsing. Extensible to parse various grammars.
+Text::Parser - Simplifies text parsing. Easily extensible to parse various text formats.
 
 =head1 VERSION
 
-version 0.902
+version 0.903
 
 =head1 SYNOPSIS
 
